@@ -1,4 +1,4 @@
-// Copyright 2021 Daniel Foehr
+// Copyright 2021 The Kubeswitch authors
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
@@ -148,6 +148,19 @@ func init() {
 		},
 	}
 
+	lastContextCmd := &cobra.Command{
+		Use:   "set-last-context",
+		Short: "Switch to the last used context from the history",
+		RunE: func(cmd *cobra.Command, args []string) error {
+			stores, config, err := initialize()
+			if err != nil {
+				return err
+			}
+
+			return history.SetLastContext(stores, config, stateDirectory, noIndex)
+		},
+	}
+
 	historyCmd := &cobra.Command{
 		Use:     "history",
 		Aliases: []string{"h"},
@@ -159,21 +172,21 @@ func init() {
 				return err
 			}
 
-			return history.ListHistory(stores, config, stateDirectory, noIndex)
+			return history.SwitchToHistory(stores, config, stateDirectory, noIndex)
 		},
 	}
 
 	setContextCmd := &cobra.Command{
 		Use:   "set-context",
 		Short: "Switch to context name provided as first argument",
-		Long:  `Switch to context name provided as first argument. Context name has to exist in any of the found Kubeconfig files.`,
+		Long:  `Switch to context name provided as first argument. KubeContext name has to exist in any of the found Kubeconfig files.`,
 		RunE: func(cmd *cobra.Command, args []string) error {
 			stores, config, err := initialize()
 			if err != nil {
 				return err
 			}
 
-			return setcontext.SetContext(args[0], stores, config, stateDirectory, noIndex)
+			return setcontext.SetContext(args[0], stores, config, stateDirectory, noIndex, true)
 		},
 	}
 
@@ -278,6 +291,7 @@ func init() {
 	rootCommand.AddCommand(hookCmd)
 	rootCommand.AddCommand(historyCmd)
 	rootCommand.AddCommand(previousContextCmd)
+	rootCommand.AddCommand(lastContextCmd)
 	rootCommand.AddCommand(aliasContextCmd)
 	rootCommand.AddCommand(versionCmd)
 
@@ -289,6 +303,7 @@ func init() {
 	setCommonFlags(listContextsCmd)
 	setCommonFlags(historyCmd)
 	setCommonFlags(previousContextCmd)
+	setCommonFlags(lastContextCmd)
 	setCommonFlags(aliasContextCmd)
 }
 
@@ -415,6 +430,12 @@ func initialize() ([]store.KubeconfigStore, *types.Config, error) {
 			}
 			s = gardenerStore
 
+		case types.StoreKindGKE:
+			gkeStore, err := store.NewGKEStore(kubeconfigStoreFromConfig, stateDirectory)
+			if err != nil {
+				return nil, nil, fmt.Errorf("unable to create GKE store: %w", err)
+			}
+			s = gkeStore
 		default:
 			return nil, nil, fmt.Errorf("unknown store %q", kubeconfigStoreFromConfig.Kind)
 		}
